@@ -1,24 +1,36 @@
+# Module docstring
 """
-.. todo:: Document :mod:`royalnet_discordpy.pda`.
+The PDA ("main" class) for the :mod:`royalnet_discordpy` frontend.
 """
 
+# Special imports
 from __future__ import annotations
 import royalnet.royaltyping as t
 
+# External imports
 import discord
 import logging
 import asyncio
 import royalnet.engineer as engi
 
-from . import bullets
+# Internal imports
+from . import magazine
 
+# Special global objects
 log = logging.getLogger(__name__)
 
 
+# Code
 class DiscordPDA(discord.AutoShardedClient):
     def __init__(self, *args, **kwargs):
         log.debug(f"Creating new DiscordPDA...")
 
+        log.debug(f"Creating new magazine...")
+        self.mag = magazine.DiscordMagazine()
+        """
+        The :class:`royalnet.engineer.magazine.Magazine` used by this PDA.
+        """
+
         log.debug(f"Subscribing to guild_messages and dm_messages by setting intents...")
         intents = discord.Intents(guilds=True, members=True, guild_messages=True, dm_messages=True)
 
@@ -70,7 +82,7 @@ class DiscordPDA(discord.AutoShardedClient):
             return
 
         log.debug(f"Creating DiscordMessage from: {message!r}")
-        bullet = bullets.DiscordMessage(_msg=message)
+        bullet = self.mag.Message(_msg=message)
 
         log.debug(f"Getting the channel of: {bullet!r}")
         channel = await bullet.channel()
@@ -112,7 +124,7 @@ class DiscordPDA(discord.AutoShardedClient):
         self.register_conversation(command)
         return command
 
-    async def put_bullet(self, channel: bullets.DiscordChannel, bullet: engi.Bullet) -> None:
+    async def put_bullet(self, channel: engi.Channel, bullet: engi.Bullet) -> None:
         """
         Insert a new bullet into the dispenser corresponding to the specified channel.
 
@@ -138,3 +150,12 @@ class DiscordPDA(discord.AutoShardedClient):
 
         log.debug(f"Putting bullet {bullet!r} in dispenser {dispenser!r}...")
         await dispenser.put(bullet)
+
+        log.debug("Awaiting another event loop cycle...")
+        await asyncio.sleep(0)
+
+
+# Objects exported by this module
+__all__ = (
+    "DiscordPDA",
+)
